==> quarkus-core-0.19.0-sources.jar: io/quarkus/runtime/logging/LogConfig$$accessor.java <==
package io.quarkus.runtime.logging;
public final class LogConfig$$accessor {
    private LogConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_categories(Object __instance) {
        return ((LogConfig)__instance).categories;
    }
    @SuppressWarnings("unchecked")
    public static void set_categories(Object __instance, Object categories) {
        ((LogConfig)__instance).categories = (java.util.Map<String, CategoryConfig>)categories;
    }
    @SuppressWarnings("unchecked")
    public static Object get_filters(Object __instance) {
        return ((LogConfig)__instance).filters;
    }
    @SuppressWarnings("unchecked")
    public static void set_filters(Object __instance, Object filters) {
        ((LogConfig)__instance).filters = (java.util.Map<String, CleanupFilterConfig>)filters;
    }
    @SuppressWarnings("unchecked")
    public static Object get_level(Object __instance) {
        return ((LogConfig)__instance).level;
    }
    @SuppressWarnings("unchecked")
    public static void set_level(Object __instance, Object level) {
        ((LogConfig)__instance).level = (java.util.Optional<java.util.logging.Level>)level;
    }
    @SuppressWarnings("unchecked")
    public static Object get_minLevel(Object __instance) {
        return ((LogConfig)__instance).minLevel;
    }
    @SuppressWarnings("unchecked")
    public static void set_minLevel(Object __instance, Object minLevel) {
        ((LogConfig)__instance).minLevel = (java.util.logging.Level)minLevel;
    }
    @SuppressWarnings("unchecked")
    public static Object get_console(Object __instance) {
        return ((LogConfig)__instance).console;
    }
    @SuppressWarnings("unchecked")
    public static void set_console(Object __instance, Object console) {
        ((LogConfig)__instance).console = (ConsoleConfig)console;
    }
    @SuppressWarnings("unchecked")
    public static Object get_file(Object __instance) {
        return ((LogConfig)__instance).file;
    }
    @SuppressWarnings("unchecked")
    public static void set_file(Object __instance, Object file) {
        ((LogConfig)__instance).file = (FileConfig)file;
    }
    public static Object construct() {
        return new LogConfig();
    }
}

==> quarkus-core-0.23.2-sources.jar: io/quarkus/runtime/logging/LogConfig$$accessor.java <==
package io.quarkus.runtime.logging;
public final class LogConfig$$accessor {
    private LogConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_categories(Object __instance) {
        return ((LogConfig)__instance).categories;
    }
    @SuppressWarnings("unchecked")
    public static void set_categories(Object __instance, Object categories) {
        ((LogConfig)__instance).categories = (java.util.Map<String, CategoryConfig>)categories;
    }
    @SuppressWarnings("unchecked")
    public static Object get_filters(Object __instance) {
        return ((LogConfig)__instance).filters;
    }
    @SuppressWarnings("unchecked")
    public static void set_filters(Object __instance, Object filters) {
        ((LogConfig)__instance).filters = (java.util.Map<String, CleanupFilterConfig>)filters;
    }
    @SuppressWarnings("unchecked")
    public static Object get_level(Object __instance) {
        return ((LogConfig)__instance).level;
    }
    @SuppressWarnings("unchecked")
    public static void set_level(Object __instance, Object level) {
        ((LogConfig)__instance).level = (java.util.Optional<java.util.logging.Level>)level;
    }
    @SuppressWarnings("unchecked")
    public static Object get_minLevel(Object __instance) {
        return ((LogConfig)__instance).minLevel;
    }
    @SuppressWarnings("unchecked")
    public static void set_minLevel(Object __instance, Object minLevel) {
        ((LogConfig)__instance).minLevel = (java.util.logging.Level)minLevel;
    }
    @SuppressWarnings("unchecked")
    public static Object get_console(Object __instance) {
        return ((LogConfig)__instance).console;
    }
    @SuppressWarnings("unchecked")
    public static void set_console(Object __instance, Object console) {
        ((LogConfig)__instance).console = (ConsoleConfig)console;
    }
    @SuppressWarnings("unchecked")
    public static Object get_file(Object __instance) {
        return ((LogConfig)__instance).file;
    }
    @SuppressWarnings("unchecked")
    public static void set_file(Object __instance, Object file) {
        ((LogConfig)__instance).file = (FileConfig)file;
    }
    @SuppressWarnings("unchecked")
    public static Object get_syslog(Object __instance) {
        return ((LogConfig)__instance).syslog;
    }
    @SuppressWarnings("unchecked")
    public static void set_syslog(Object __instance, Object syslog) {
        ((LogConfig)__instance).syslog = (SyslogConfig)syslog;
    }
    public static Object construct() {
        return new LogConfig();
    }
}
